@@ -366,7 +366,6 @@ def _imwrite_pil(filename, arr):
 def _import_dcm():
     """DICOM Import function (checking for required libraries):
     DICOM support requires library `pydicom`"""
-
     logger = logging.getLogger("pydicom")
     logger.setLevel(logging.CRITICAL)
 
@@ -419,8 +418,7 @@ def _imread_dcm(filename, **kwargs):
                 arr = arr.reshape(spp, dcm.Rows, dcm.Columns)
             else:
                 raise NotImplementedError(
-                    "This code only handles "
-                    "SamplesPerPixel > 1 if Bits Allocated = 8"
+                    "This code only handles SamplesPerPixel > 1 if Bits Allocated = 8"
                 )
         else:
             arr = arr.reshape(dcm.Rows, dcm.Columns)
@@ -436,11 +434,11 @@ def _imwrite_dcm(filename, arr, template=None):
         "The `template` keyword argument is required to save DICOM files\n"
         "(that is the template DICOM structure object)"
     )
-    infos = np.iinfo(arr.dtype)
-    template.BitsAllocated = infos.bits
-    template.BitsStored = infos.bits
-    template.HighBit = infos.bits - 1
-    template.PixelRepresentation = ("u", "i").index(infos.kind)
+    info = np.iinfo(arr.dtype)
+    template.BitsAllocated = info.bits
+    template.BitsStored = info.bits
+    template.HighBit = info.bits - 1
+    template.PixelRepresentation = ("u", "i").index(info.kind)
     data_vr = ("US", "SS")[template.PixelRepresentation]
     template.Rows = arr.shape[0]
     template.Columns = arr.shape[1]
@@ -607,6 +605,7 @@ register_serializable_items(
         "MaskedXYImageItem",
         "Marker",
         "XRangeSelection",
+        "YRangeSelection",
         "PolygonShape",
         "PointShape",
         "SegmentShape",
@@ -616,6 +615,8 @@ register_serializable_items(
         "Axes",
         "AnnotatedPoint",
         "AnnotatedSegment",
+        "AnnotatedXRange",
+        "AnnotatedYRange",
         "AnnotatedRectangle",
         "AnnotatedObliqueRectangle",
         "AnnotatedEllipse",
