@@ -11,6 +11,8 @@ from .annotation import (
     AnnotatedRectangle,
     AnnotatedPolygon,
     AnnotatedSegment,
+    AnnotatedXRange,
+    AnnotatedYRange,
     AnnotatedShape,
 )
 from .contour import ContourItem, create_contour_items
@@ -46,6 +48,8 @@ from .label import (
     LegendBoxItem,
     ObjectInfo,
     RangeComputation,
+    XRangeComputation,
+    YRangeComputation,
     RangeComputation2d,
     RangeInfo,
     SelectedLegendBoxItem,
@@ -65,4 +69,5 @@ from .shape import (
     SegmentShape,
     SquareSVGShape,
     XRangeSelection,
+    YRangeSelection,
 )
