@@ -28,6 +28,7 @@ from plotpy.items.shape.base import AbstractShape
 from plotpy.items.shape.ellipse import EllipseShape
 from plotpy.items.shape.point import PointShape
 from plotpy.items.shape.polygon import PolygonShape
+from plotpy.items.shape.range import XRangeSelection, YRangeSelection
 from plotpy.items.shape.rectangle import ObliqueRectangleShape, RectangleShape
 from plotpy.items.shape.segment import SegmentShape
 from plotpy.mathutils.geometry import (
@@ -74,7 +75,7 @@ class AnnotatedShape(AbstractShape):
 
             def info_callback(annotation: AnnotatedShape) -> str:
                 """Return information on annotation"""
-                return annotation.get_infos()
+                return annotation.get_info()
 
         self.info_callback = info_callback
         self.shape: AbstractShape = self.create_shape()
@@ -169,6 +170,16 @@ class AnnotatedShape(AbstractShape):
         if self.label.isVisible():
             self.label.draw(painter, xMap, yMap, canvasRect)
 
+    # ----AbstractShape API------------------------------------------------------
+    def set_readonly(self, state: bool) -> None:
+        """Set object readonly state
+
+        Args:
+            state: True if object is readonly, False otherwise
+        """
+        super().set_readonly(state)
+        self.shape.set_readonly(state)
+
     # ----Public API-------------------------------------------------------------
     def create_shape(self):
         """Return the shape object associated to this annotated shape object"""
@@ -184,6 +195,8 @@ class AnnotatedShape(AbstractShape):
         label_param = LabelParam(_("Label"), icon="label.png")
         label_param.read_config(CONF, "plot", "shape/label")
         label_param.anchor = self.LABEL_ANCHOR
+        if self.LABEL_ANCHOR == "C":
+            label_param.xc = label_param.yc = 0
         return DataInfoLabel(label_param, [self])
 
     def is_label_visible(self) -> bool:
@@ -231,11 +244,11 @@ class AnnotatedShape(AbstractShape):
                 text += "<br>"
             text += f"<i>{subtitle}</i>"
         if self.area_computations_visible:
-            infos = self.info_callback(self)
-            if infos:
+            info = self.info_callback(self)
+            if info:
                 if text:
                     text += "<br>"
-                text += infos
+                text += info
         return text
 
     def x_to_str(self, x: float) -> str:
@@ -304,7 +317,7 @@ class AnnotatedShape(AbstractShape):
         xs, ys = self.get_tr_size()
         return f"{self.x_to_str(xs)} x {self.y_to_str(ys)}"
 
-    def get_infos(self) -> str:
+    def get_info(self) -> str:
         """Get informations on current shape
 
         Returns:
@@ -525,7 +538,7 @@ class AnnotatedPoint(AnnotatedShape):
         xt, yt = self.apply_transform_matrix(*self.shape.points[0])
         return xt, yt
 
-    def get_infos(self) -> str:
+    def get_info(self) -> str:
         """Get informations on current shape
 
         Returns:
@@ -593,7 +606,7 @@ class AnnotatedSegment(AnnotatedShape):
         self.label.set_pos(*compute_center(x1, y1, x2, y2))
 
     # ----AnnotatedShape API-----------------------------------------------------
-    def get_infos(self) -> str:
+    def get_info(self) -> str:
         """Get informations on current shape
 
         Returns:
@@ -607,6 +620,247 @@ class AnnotatedSegment(AnnotatedShape):
         )
 
 
+class BaseAnnotatedRangeSelection(AnnotatedShape):
+    """
+    Construct an annotated range selection with properties set with
+    *annotationparam* (see :py:class:`.styles.AnnotationParam`)
+
+    Args:
+        annotationparam: Annotation parameters
+        info_callback: Callback to get information on the shape
+    """
+
+    _icon_name = ""  # to be overridden
+    SHAPE_CLASS: type[AbstractShape] = XRangeSelection  # to be overridden
+
+    def __init__(
+        self,
+        _min: float | None = None,
+        _max: float | None = None,
+        annotationparam: AnnotationParam | None = None,
+        info_callback: Callable[[AnnotatedShape], str] | None = None,
+    ) -> None:
+        super().__init__(annotationparam, info_callback)
+        self.shape: XRangeSelection | YRangeSelection
+        self.shape.set_private(True)
+        self.set_range(_min, _max)
+
+    # ----Public API-------------------------------------------------------------
+    def set_range(self, _min: float | None, _max: float | None) -> None:
+        """Set the range selection coordinates
+
+        Args:
+            _min: Minimum value
+            _max: Maximum value
+        """
+        self.shape.set_range(_min, _max)
+        self.set_label_position()
+
+    def get_range(self) -> tuple[float, float]:
+        """Return the range selection coordinates
+
+        Returns:
+            Range selection coordinates as a tuple (min, max)
+        """
+        return self.shape.get_range()
+
+    def get_tr_range(self) -> float:
+        """Return the range selection length after applying transform matrix
+
+        Returns:
+            Range selection length after applying transform matrix
+        """
+        return compute_distance(*self.get_transformed_coords(0, 1))
+
+    def get_tr_center(self) -> float:
+        """Return the range selection position (middle) after applying transform matrix
+
+        Returns:
+            Range selection position (middle) after applying transform matrix
+        """
+        center = compute_center(*self.get_transformed_coords(0, 1))
+        if isinstance(self.shape, XRangeSelection):
+            return center[0]
+        return center[1]
+
+    # pylint: disable=unused-argument
+    def get_transformed_coords(self, handle1, handle2):
+        """
+
+        :param handle1:
+        :param handle2:
+        :return:
+        """
+        x1, x2 = self.get_range()
+        y1 = y2 = 0.0
+        if isinstance(self.shape, YRangeSelection):
+            x1, x2, y1, y2 = y1, y2, x1, x2
+        x1, y1 = self.apply_transform_matrix(x1, y1)
+        x2, y2 = self.apply_transform_matrix(x2, y2)
+        return x1, y1, x2, y2
+
+    # ----AnnotatedShape API-----------------------------------------------------
+    def create_shape(self):
+        """Return the shape object associated to this annotated shape object"""
+        shape = self.SHAPE_CLASS(0, 0)
+        return shape
+
+    def get_info(self) -> str:
+        """Get informations on current shape
+
+        Returns:
+            str: Formatted string with informations on current shape
+        """
+        coord_str = "x" if isinstance(self.shape, XRangeSelection) else "y"
+        c, r = self.get_tr_center(), self.get_tr_range()
+        center_val = self.x_to_str(c)
+        range_val = self.x_to_str(r)
+        lower_val = self.x_to_str(c - 0.5 * r)
+        upper_val = self.x_to_str(c + 0.5 * r)
+        return "<br>".join(
+            [
+                f"{coord_str}<sub>C</sub> = {center_val}",
+                f"{coord_str}<sub>MIN</sub> = {lower_val}",
+                f"{coord_str}<sub>MAX</sub> = {upper_val}",
+                f"Δ{coord_str} = {range_val}",
+            ]
+        )
+
+    # ----IBasePlotItem API------------------------------------------------------
+    def hit_test(self, pos: QPointF) -> tuple[float, float, bool, None]:
+        """Return a tuple (distance, attach point, inside, other_object)
+
+        Args:
+            pos: Position
+
+        Returns:
+            tuple: Tuple with four elements: (distance, attach point, inside,
+             other_object).
+
+        Description of the returned values:
+
+        * distance: distance in pixels (canvas coordinates) to the closest
+           attach point
+        * attach point: handle of the attach point
+        * inside: True if the mouse button has been clicked inside the object
+        * other_object: if not None, reference of the object which will be
+           considered as hit instead of self
+        """
+        return self.shape.hit_test(pos)
+
+    # ----QwtPlotItem API--------------------------------------------------------
+    def draw(
+        self,
+        painter: QPainter,
+        xMap: qwt.scale_map.QwtScaleMap,
+        yMap: qwt.scale_map.QwtScaleMap,
+        canvasRect: QRectF,
+    ) -> None:
+        """Draw the item
+
+        Args:
+            painter: Painter
+            xMap: X axis scale map
+            yMap: Y axis scale map
+            canvasRect: Canvas rectangle
+        """
+        self.set_label_position()
+        super().draw(painter, xMap, yMap, canvasRect)
+
+    def attach(self, plot):
+        """
+        Attach the item to a plot.
+
+        This method will attach a `QwtPlotItem` to the `QwtPlot` argument.
+        It will first detach the `QwtPlotItem` from any plot from a previous
+        call to attach (if necessary). If a None argument is passed, it will
+        detach from any `QwtPlot` it was attached to.
+
+        :param qwt.plot.QwtPlot plot: Plot widget
+
+        .. seealso::
+
+            :py:meth:`detach()`
+        """
+        super().attach(plot)
+        self.shape.attach(plot)
+        self.set_label_position()
+
+
+class AnnotatedXRange(BaseAnnotatedRangeSelection):
+    """
+    Construct an annotated X range selection with properties set with
+    *annotationparam* (see :py:class:`.styles.AnnotationParam`)
+
+    Args:
+        _min: Minimum value
+        _max: Maximum value
+        annotationparam: Annotation parameters
+        info_callback: Callback to get information on the shape
+    """
+
+    _icon_name = "xrange.png"
+    SHAPE_CLASS = XRangeSelection
+    LABEL_ANCHOR = "C"
+
+    def __init__(
+        self,
+        _min: float | None = None,
+        _max: float | None = None,
+        annotationparam: AnnotationParam | None = None,
+        info_callback: Callable[[AnnotatedShape], str] | None = None,
+    ) -> None:
+        super().__init__(_min, _max, annotationparam, info_callback)
+
+    # ----AnnotatedShape API-----------------------------------------------------
+    def set_label_position(self) -> None:
+        """Set label position, for instance based on shape position"""
+        plot = self.plot()
+        if plot is not None:
+            x0, x1, y = self.shape.get_handles_pos()
+            x = 0.5 * (x0 + x1)
+            x = plot.invTransform(self.xAxis(), x)
+            y = plot.invTransform(self.yAxis(), y)
+            self.label.set_pos(x, y)
+
+
+class AnnotatedYRange(BaseAnnotatedRangeSelection):
+    """
+    Construct an annotated Y range selection with properties set with
+    *annotationparam* (see :py:class:`.styles.AnnotationParam`)
+
+    Args:
+        _min: Minimum value
+        _max: Maximum value
+        annotationparam: Annotation parameters
+        info_callback: Callback to get information on the shape
+    """
+
+    _icon_name = "yrange.png"
+    SHAPE_CLASS = YRangeSelection
+    LABEL_ANCHOR = "C"
+
+    def __init__(
+        self,
+        _min: float | None = None,
+        _max: float | None = None,
+        annotationparam: AnnotationParam | None = None,
+        info_callback: Callable[[AnnotatedShape], str] | None = None,
+    ) -> None:
+        super().__init__(_min, _max, annotationparam, info_callback)
+
+    # ----AnnotatedShape API-----------------------------------------------------
+    def set_label_position(self) -> None:
+        """Set label position, for instance based on shape position"""
+        plot = self.plot()
+        if plot is not None:
+            y0, y1, x = self.shape.get_handles_pos()
+            y = 0.5 * (y0 + y1)
+            x = plot.invTransform(self.xAxis(), x)
+            y = plot.invTransform(self.yAxis(), y)
+            self.label.set_pos(x, y)
+
+
 class AnnotatedPolygon(AnnotatedShape):
     """
     Construct an annotated polygon with properties set with *annotationparam*
@@ -754,7 +1008,7 @@ class AnnotatedPolygon(AnnotatedShape):
         """Return shape center coordinates after applying transform matrix"""
         return self.shape.get_center()
 
-    def get_infos(self) -> str:
+    def get_info(self) -> str:
         """Get informations on current shape
 
         Returns:
@@ -820,7 +1074,7 @@ class AnnotatedRectangle(AnnotatedShape):
         """Return shape size after applying transform matrix"""
         return compute_rect_size(*self.get_transformed_coords(0, 2))
 
-    def get_infos(self) -> str:
+    def get_info(self) -> str:
         """Get informations on current shape
 
         Returns:
@@ -912,7 +1166,7 @@ class AnnotatedObliqueRectangle(AnnotatedRectangle):
         return dx, dy
 
     # ----AnnotatedShape API-----------------------------------------------------
-    def get_infos(self) -> str:
+    def get_info(self) -> str:
         """Get informations on current shape
 
         Returns:
@@ -1033,7 +1287,7 @@ class AnnotatedEllipse(AnnotatedShape):
             dx, dy = dy, dx
         return dx, dy
 
-    def get_infos(self) -> str:
+    def get_info(self) -> str:
         """Get informations on current shape
 
         Returns:
@@ -1064,7 +1318,7 @@ class AnnotatedCircle(AnnotatedEllipse):
         return compute_distance(*self.get_transformed_coords(0, 1))
 
     # ----AnnotatedShape API-------------------------------------------------
-    def get_infos(self) -> str:
+    def get_info(self) -> str:
         """Get informations on current shape
 
         Returns:
