@@ -24,7 +24,6 @@ from __future__ import annotations
 
 import guidata.dataset as gds
 import numpy as np
-from guidata.configtools import get_icon
 from guidata.utils.misc import assert_interfaces_valid
 from skimage import measure
 
@@ -110,10 +109,10 @@ class ContourItem(PolygonShape):
     _can_resize = False
     _can_rotate = False
     _can_move = False
+    _icon_name = "contour.png"
 
     def __init__(self, points=None, shapeparam=None):
         super().__init__(points, closed=True, shapeparam=shapeparam)
-        self.setIcon(get_icon("contour.png"))
 
 
 assert_interfaces_valid(ContourItem)
