@@ -6,7 +6,6 @@ import sys
 from typing import TYPE_CHECKING
 
 import numpy as np
-from guidata.configtools import get_icon
 from guidata.dataset import update_dataset
 from guidata.utils.misc import assert_interfaces_valid
 from qtpy import QtCore as QC
@@ -27,6 +26,7 @@ if TYPE_CHECKING:
     import guidata.io
 
     from plotpy.interfaces import IItemType
+    from plotpy.plot import BasePlot
     from plotpy.styles.base import ItemParameters
 
 
@@ -111,6 +111,7 @@ class CurveItem(QwtPlotCurve):
 
     _readonly = False
     _private = False
+    _icon_name = "curve.png"
 
     def __init__(self, curveparam: CurveParam | None = None) -> None:
         super().__init__()
@@ -123,7 +124,6 @@ class CurveItem(QwtPlotCurve):
         self._x = None
         self._y = None
         self.update_params()
-        self.setIcon(get_icon("curve.png"))
 
     def _get_visible_axis_min(self, axis_id: int, axis_data: np.ndarray) -> float:
         """Return axis minimum excluding zero and negative values when
@@ -172,6 +172,22 @@ class CurveItem(QwtPlotCurve):
         """
         return (ICurveItemType, ITrackableItemType, ISerializableType)
 
+    def get_icon_name(self) -> str:
+        """Return the icon name
+
+        Returns:
+            Icon name
+        """
+        return self._icon_name
+
+    def set_icon_name(self, icon_name: str) -> None:
+        """Set the icon name
+
+        Args:
+            icon_name: Icon name
+        """
+        self._icon_name = icon_name
+
     def set_selectable(self, state: bool) -> None:
         """Set item selectable state
 
@@ -488,7 +504,16 @@ class CurveItem(QwtPlotCurve):
             str: Coordinates label
         """
         title = self.title().text()
-        return f"{title}:<br>x = {x:g}<br>y = {y:g}"
+
+        # Use the plot's consolidated coordinate formatting method
+        plot: BasePlot = self.plot()
+        if plot is not None:
+            # Format using the plot's consolidated coordinate formatting method
+            return plot.format_coordinate_values(
+                x, y, self.xAxis(), self.yAxis(), title
+            )
+        else:
+            return f"{title}:<br>x = {x:g}<br>y = {y:g}"
 
     def get_closest_x(self, xc: float) -> tuple[float, float]:
         """
