@@ -10,12 +10,11 @@ import os.path as osp
 from typing import TYPE_CHECKING, Any
 
 import numpy as np
-from guidata.configtools import get_icon
 from guidata.dataset import update_dataset
 from guidata.utils.misc import assert_interfaces_valid
 from qtpy import QtCore as QC
 from qtpy import QtGui as QG
-from qwt import QwtPlotItem
+from qwt import QwtLinearScaleEngine, QwtPlotItem
 
 from plotpy import io
 from plotpy._scaler import (
@@ -56,6 +55,7 @@ if TYPE_CHECKING:
     from qtpy.QtGui import QColor, QPainter
 
     from plotpy.interfaces import IItemType
+    from plotpy.plot import BasePlot
     from plotpy.styles.base import ItemParameters
     from plotpy.widgets.colormap.widget import EditableColormap
 
@@ -82,6 +82,7 @@ class BaseImageItem(QwtPlotItem):
     _can_rotate = False
     _readonly = False
     _private = False
+    _icon_name = "image.png"
 
     def __init__(
         self, data: np.ndarray | None = None, param: Any | None = None
@@ -134,7 +135,6 @@ class BaseImageItem(QwtPlotItem):
         if data is not None:
             self.set_data(data)
         self.param.update_item(self)
-        self.setIcon(get_icon("image.png"))
 
     # ---- Public API ----------------------------------------------------------
     def get_default_param(self) -> Any:
@@ -216,34 +216,44 @@ class BaseImageItem(QwtPlotItem):
         return i, j
 
     def get_closest_index_rect(
-        self, x0: float, y0: float, x1: float, y1: float
+        self, x0: float, y0: float, x1: float, y1: float, avoid_empty: bool = True
     ) -> tuple[int, int, int, int]:
-        """Get closest image rectangular pixel area index bounds
+        """Get closest image rectangular pixel area index bounds, optionally
+        avoid returning an empty rectangular area (return at least 1x1 pixel area)
 
         Args:
             x0: X coordinate of first point
             y0: Y coordinate of first point
             x1: X coordinate of second point
             y1: Y coordinate of second point
+            avoid_empty: True to avoid returning an empty rectangular area.
+             Defaults to True.
 
         Returns:
-            Closest image rectangular pixel area index bounds
+            Closest image rectangular pixel area index bounds compatible with
+            direct array slicing (e.g., data[iy0:iy1, ix0:ix1])
 
         .. note::
 
             Avoid returning empty rectangular area (return 1x1 pixel area instead).
             Handle reversed/not-reversed Y-axis orientation.
+            Indices are compatible with direct array slicing and match get_data
+            behavior.
         """
         ix0, iy0 = self.get_closest_indexes(x0, y0, corner="TL")
-        ix1, iy1 = self.get_closest_indexes(x1, y1, corner="BR")
+        # Use TL to avoid double +1 addition
+        ix1, iy1 = self.get_closest_indexes(x1, y1, corner="TL")
         if ix0 > ix1:
             ix1, ix0 = ix0, ix1
         if iy0 > iy1:
             iy1, iy0 = iy0, iy1
-        if ix0 == ix1:
-            ix1 += 1
-        if iy0 == iy1:
-            iy1 += 1
+        # Add +1 to bottom-right indices for slice compatibility (matches get_data)
+        ix1 = min(ix1 + 1, self.data.shape[1])
+        iy1 = min(iy1 + 1, self.data.shape[0])
+        if ix0 == ix1 and avoid_empty:
+            ix1 = min(ix1 + 1, self.data.shape[1])
+        if iy0 == iy1 and avoid_empty:
+            iy1 = min(iy1 + 1, self.data.shape[0])
         return ix0, iy0, ix1, iy1
 
     def align_rectangular_shape(self, shape: RectangleShape) -> None:
@@ -583,6 +593,29 @@ class BaseImageItem(QwtPlotItem):
         """
         self.border_rect.draw(painter, xMap, yMap, canvasRect)
 
+    def warn_if_non_linear_scale(self, painter: QPainter, canvasRect: QRectF) -> bool:
+        """Warn if non-linear scale
+
+        Args:
+            painter: Painter
+            canvasRect: Canvas rectangle
+
+        Returns:
+            True if non-linear scale
+        """
+        plot: BasePlot = self.plot()
+        if not isinstance(
+            plot.axisScaleEngine(plot.X_BOTTOM), QwtLinearScaleEngine
+        ) or not isinstance(plot.axisScaleEngine(plot.Y_LEFT), QwtLinearScaleEngine):
+            painter.setPen(QC.Qt.red)
+            painter.drawText(
+                canvasRect,
+                QC.Qt.AlignCenter,
+                _("Non-linear scales are not supported for image items"),
+            )
+            return True
+        return False
+
     def draw_image(
         self,
         painter: QPainter,
@@ -602,6 +635,8 @@ class BaseImageItem(QwtPlotItem):
             xMap: X axis scale map
             yMap: Y axis scale map
         """
+        if self.warn_if_non_linear_scale(painter, canvasRect):
+            return
         dest = _scale_rect(
             self.data, src_rect, self._offscreen, dst_rect, self.lut, self.interpolate
         )
@@ -777,6 +812,22 @@ class BaseImageItem(QwtPlotItem):
         """
         return self.data is None or self.data.size == 0
 
+    def get_icon_name(self) -> str:
+        """Return the icon name
+
+        Returns:
+            Icon name
+        """
+        return self._icon_name
+
+    def set_icon_name(self, icon_name: str) -> None:
+        """Set the icon name
+
+        Args:
+            icon_name: Icon name
+        """
+        self._icon_name = icon_name
+
     def set_selectable(self, state: bool) -> None:
         """Set item selectable state
 
@@ -1042,7 +1093,9 @@ class BaseImageItem(QwtPlotItem):
         Returns:
             Average cross section along x-axis
         """
-        ix0, iy0, ix1, iy1 = self.get_closest_index_rect(x0, y0, x1, y1)
+        ix0, iy0, ix1, iy1 = self.get_closest_index_rect(
+            x0, y0, x1, y1, avoid_empty=False
+        )
         ydata = self.data[iy0:iy1, ix0:ix1]
         if ydata.size == 0:
             return np.array([]), np.array([])
@@ -1067,7 +1120,9 @@ class BaseImageItem(QwtPlotItem):
         Returns:
             Average cross section along y-axis
         """
-        ix0, iy0, ix1, iy1 = self.get_closest_index_rect(x0, y0, x1, y1)
+        ix0, iy0, ix1, iy1 = self.get_closest_index_rect(
+            x0, y0, x1, y1, avoid_empty=False
+        )
         ydata = self.data[iy0:iy1, ix0:ix1]
         if ydata.size == 0:
             return np.array([]), np.array([])
