@@ -15,10 +15,11 @@ from plotpy.config import _
 from plotpy.interfaces import (
     IBaseImageItem,
     IBasePlotItem,
+    IExportROIImageItemType,
     IHistDataSource,
     IVoiImageItemType,
 )
-from plotpy.items.image.image_items import ImageItem, XYImageItem
+from plotpy.items.image.standard import ImageItem, XYImageItem
 from plotpy.styles.image import MaskedImageParam, MaskedXYImageParam
 
 if TYPE_CHECKING:
@@ -149,13 +150,25 @@ class MaskedImageMixin:
     def update_mask(self) -> None:
         """Update mask"""
         if isinstance(self.data, np.ma.MaskedArray):
-
-            # Casting filling_value to data dtype, otherwise this may raise an error
-            # in future versions of NumPy (at the time of writing, this raises a
-            # DeprecationWarning "NumPy will stop allowing conversion of out-of-bound
-            # Python integers to integer arrays.")
-            val = np.array(self.param.filling_value).astype(self.data.dtype)
-
+            filling_value = self.param.filling_value
+            if filling_value is None or (
+                isinstance(filling_value, float) and np.isnan(filling_value)
+            ):
+                # Use a safe default for integer types when filling_value is None or NaN
+                if np.issubdtype(self.data.dtype, np.integer):
+                    val = np.array(0, dtype=self.data.dtype)
+                else:
+                    val = np.array(np.nan, dtype=self.data.dtype)
+            else:
+                # If filling_value is out of bounds for data dtype, get the default
+                # fill value for that dtype
+                if np.issubdtype(self.data.dtype, np.integer):
+                    info = np.iinfo(self.data.dtype)
+                    if filling_value < info.min or filling_value > info.max:
+                        # Using the default fill value thanks to the get_fill_value()
+                        # method of MaskedArray:
+                        filling_value = self.data.get_fill_value()
+                val = np.array(filling_value).astype(self.data.dtype)
             self.data.set_fill_value(val)
 
     def set_mask(self, mask: ma.MaskedArray) -> None:
@@ -407,7 +420,13 @@ class MaskedImageItem(ImageItem, MaskedImageMixin):
         param: image parameters
     """
 
-    __implements__ = (IBasePlotItem, IBaseImageItem, IHistDataSource, IVoiImageItemType)
+    __implements__ = (
+        IBasePlotItem,
+        IBaseImageItem,
+        IHistDataSource,
+        IVoiImageItemType,
+        IExportROIImageItemType,
+    )
 
     def __init__(
         self,
@@ -571,7 +590,13 @@ class MaskedXYImageItem(XYImageItem, MaskedImageMixin):
         param: image parameters
     """
 
-    __implements__ = (IBasePlotItem, IBaseImageItem, IHistDataSource, IVoiImageItemType)
+    __implements__ = (
+        IBasePlotItem,
+        IBaseImageItem,
+        IHistDataSource,
+        IVoiImageItemType,
+        IExportROIImageItemType,
+    )
 
     def __init__(
         self,
