@@ -6,7 +6,6 @@ import sys
 from typing import TYPE_CHECKING
 
 import numpy as np
-from guidata.configtools import get_icon
 from guidata.dataset import update_dataset
 from guidata.utils.misc import assert_interfaces_valid
 from qtpy import QtCore as QC
@@ -40,7 +39,7 @@ except ImportError:
         file=sys.stderr,
     )
     print(
-        ("try running :" "python setup.py build_ext --inplace -c mingw32"),
+        ("try running: python setup.py build_ext --inplace"),
         file=sys.stderr,
     )
     raise
@@ -170,6 +169,8 @@ class QuadGridItem(RawImageItem):
             xMap: X axis scale map
             yMap: Y axis scale map
         """
+        if self.warn_if_non_linear_scale(painter, canvasRect):
+            return
         self._offscreen[...] = np.uint32(0)
         dest = _scale_quads(
             self.X,
@@ -206,6 +207,7 @@ class Histogram2DItem(BaseImageItem):
     """
 
     __implements__ = (IBasePlotItem, IBaseImageItem, IHistDataSource, IVoiImageItemType)
+    _icon_name = "histogram2d.png"
 
     def __init__(
         self,
@@ -234,7 +236,6 @@ class Histogram2DItem(BaseImageItem):
 
         self.set_lut_range([0, 10.0])
         self.set_data(X, Y, Z)
-        self.setIcon(get_icon("histogram2d.png"))
 
     # ---- BaseImageItem API ---------------------------------------------------
     def get_default_param(self) -> Histogram2DParam:
@@ -295,6 +296,8 @@ class Histogram2DItem(BaseImageItem):
             xMap: X axis scale map
             yMap: Y axis scale map
         """
+        if self.warn_if_non_linear_scale(painter, canvasRect):
+            return
         computation = self.histparam.computation
         i1, j1, i2, j2 = src_rect
 
@@ -341,7 +344,7 @@ class Histogram2DItem(BaseImageItem):
             return BaseImageItem.draw_image(self, *args)
 
         if self.fill_canvas:
-            x1, y1, x2, y2 = canvasRect.getCoords()
+            x1, y1, x2, y2 = canvasRect.toAlignedRect().getCoords()
             drawfunc(painter, canvasRect, src_rect, (x1, y1, x2, y2), xMap, yMap)
         else:
             dst_rect = tuple([int(i) for i in dst_rect])
@@ -471,10 +474,6 @@ def assemble_imageitems(
 
     Returns:
         Pixel data
-
-    .. warning::
-
-        Does not support `XYImageItem` objects
     """
     # align width to 'align' bytes
     if align is not None:
@@ -508,6 +507,8 @@ def assemble_imageitems(
     src_rect[1] += 0.5 * pixel_height
     src_rect[2] -= 0.5 * pixel_width
     src_rect[3] -= 0.5 * pixel_height
+    # Convert to tuple for compatibility with C extension
+    src_rect = tuple(src_rect)
 
     for it in sorted(items, key=lambda obj: obj.z()):
         if it.isVisible() and src_qrect.intersects(it.boundingRect()):
@@ -734,11 +735,6 @@ def get_image_from_plot(
 
     Returns:
         Image pixel data
-
-    .. warning::
-
-        Support only the image items implementing the `IExportROIImageItemType`
-        interface, i.e. this does *not* support `XYImageItem` objects
     """
     if destw is None:
         destw = p1.x() - p0.x() + 1
