@@ -13,10 +13,10 @@ plotpy.widgets.label
 
 from __future__ import annotations
 
+import re
 from typing import TYPE_CHECKING, Any
 
 import numpy as np
-from guidata.configtools import get_icon
 from guidata.dataset import update_dataset
 from guidata.utils.misc import assert_interfaces_valid
 from qtpy import QtCore as QC
@@ -27,6 +27,7 @@ from plotpy.config import CONF, _
 from plotpy.coords import canvas_to_axes
 from plotpy.interfaces import IBasePlotItem, ISerializableType, IShapeItemType
 from plotpy.items.curve.base import CurveItem
+from plotpy.items.shape.range import XRangeSelection
 from plotpy.styles.label import LabelParam
 
 if TYPE_CHECKING:
@@ -39,7 +40,7 @@ if TYPE_CHECKING:
     from qtpy.QtGui import QBrush, QPainter, QPen, QTextDocument
 
     from plotpy.interfaces import IItemType
-    from plotpy.items import ImageItem, RectangleShape, XRangeSelection
+    from plotpy.items import ImageItem, RectangleShape, YRangeSelection
     from plotpy.styles.base import ItemParameters
 
 ANCHORS = {
@@ -207,6 +208,22 @@ class AbstractLabelItem(QwtPlotItem):
             y0 = yMap.transform(self.G[1])
             return x0, y0
 
+    def get_icon_name(self) -> str:
+        """Return the icon name
+
+        Returns:
+            Icon name
+        """
+        return self._icon_name
+
+    def set_icon_name(self, icon_name: str) -> None:
+        """Set the icon name
+
+        Args:
+            icon_name: Icon name
+        """
+        self._icon_name = icon_name
+
     def set_selectable(self, state: bool) -> None:
         """Set item selectable state
 
@@ -437,6 +454,10 @@ class AbstractLabelItem(QwtPlotItem):
             lx, ly = self.C
             lx += new_pos.x() - old_pos.x()
             ly += new_pos.y() - old_pos.y()
+            lx, ly = (
+                int(lx),
+                int(ly),
+            )  # Convert to integer (expected type for canvas coordinates)
             self.C = lx, ly
             self.labelparam.xc, self.labelparam.yc = lx, ly
             lx0, ly0 = canvas_to_axes(self, old_pos)
@@ -497,6 +518,7 @@ class LabelItem(AbstractLabelItem):
     """
 
     __implements__ = (IBasePlotItem, ISerializableType)
+    _icon_name = "label.png"
 
     def __init__(
         self, text: str | None = None, labelparam: LabelParam | None = None
@@ -505,7 +527,6 @@ class LabelItem(AbstractLabelItem):
         self.text = QG.QTextDocument()
         self.marker: qwt.symbol.QwtSymbol | None = None
         super().__init__(labelparam)
-        self.setIcon(get_icon("label.png"))
 
     def __reduce__(self) -> tuple[type, tuple]:
         """Return a tuple containing the constructor and its arguments"""
@@ -645,6 +666,7 @@ class LegendBoxItem(AbstractLabelItem):
     """
 
     __implements__ = (IBasePlotItem, ISerializableType)
+    _icon_name = "legend.png"
 
     def __init__(self, labelparam: LabelParam = None) -> None:
         self.font = None
@@ -652,7 +674,6 @@ class LegendBoxItem(AbstractLabelItem):
         super().__init__(labelparam)
         # saves the last computed sizes
         self.sizes = 0.0, 0.0, 0.0, 0.0
-        self.setIcon(get_icon("legend.png"))
 
     def types(self) -> tuple[type[IItemType], ...]:
         """Returns a group or category for this item.
@@ -891,20 +912,100 @@ class ObjectInfo:
         """Return the text to be displayed"""
         return ""
 
+    @staticmethod
+    def _replace_format_specifiers(label: str, datetime_positions: list[int]) -> str:
+        """Replace numeric format specifiers with %s for datetime positions
+
+        Args:
+            label: The label format string
+            datetime_positions: List of positions that should use %s
+
+        Returns:
+            Modified label string
+        """
+        # Find all format specifiers
+        pattern = r"%[+-]?(?:\d+)?(?:\.\d+)?[hlL]?[diouxXeEfFgGcrs%]"
+        matches = list(re.finditer(pattern, label))
+
+        # Replace numeric formats with %s for datetime positions
+        result = label
+        offset = 0
+        spec_index = 0
+
+        for match in matches:
+            if match.group() == "%%":  # Skip escaped %
+                continue
+
+            if spec_index in datetime_positions:
+                # Replace this format specifier with %s
+                old_spec = match.group()
+                new_spec = "%s"
+                start = match.start() + offset
+                end = match.end() + offset
+                result = result[:start] + new_spec + result[end:]
+                offset += len(new_spec) - len(old_spec)
+
+            spec_index += 1
+
+        return result
+
+    @staticmethod
+    def _format_values_for_datetime_axis(
+        plot, axis_id: int, label: str, result: tuple | list, value_checker: Callable
+    ) -> tuple[str, tuple]:
+        """Format values as datetime strings if they match the value_checker criterion
+
+        Args:
+            plot: The plot object
+            axis_id: The axis ID to check for datetime scale
+            label: The label format string
+            result: The result tuple/list from the function
+            value_checker: Function that takes (value, index) and returns True if the
+             value should be formatted as datetime
+
+        Returns:
+            Tuple of (adjusted_label, formatted_result)
+        """
+        # Check if axis is datetime
+        if plot.get_axis_scale(axis_id) != "datetime":
+            return label, result
+
+        # Convert result to list for modification
+        if not isinstance(result, (list, tuple)):
+            result = [result]
+        else:
+            result = list(result)
+
+        # Find positions that need datetime formatting
+        datetime_positions = []
+        for i, val in enumerate(result):
+            if isinstance(val, (int, float, np.number)) and not np.isnan(val):
+                if value_checker(val, i):
+                    datetime_positions.append(i)
+                    # Format as datetime string
+                    result[i] = plot.format_coordinate_value(val, axis_id)
+
+        # Replace format specifiers for datetime positions in the label
+        if datetime_positions:
+            label = ObjectInfo._replace_format_specifiers(label, datetime_positions)
+
+        return label, tuple(result)
+
 
 class RangeInfo(ObjectInfo):
-    """ObjectInfo handling XRangeSelection shape informations: x, dx
+    """ObjectInfo handling `XRangeSelection` or `YRangeSelection`
+    shape informations: x, dx or y, dy
 
     Args:
         label: Formatted string
-        xrangeselection: XRangeSelection object
+        xrangeselection: `XRangeSelection` or `YRangeSelection` object
         function: Input arguments are x, dx ; returns objects used to format the
          label. Default function is `lambda x, dx: (x, dx)`.
 
     Examples::
         x = linspace(-10, 10, 10)
         y = sin(sin(sin(x)))
-        xrangeselection = make.range(-2, 2)
+        xrangeselection = make.xrange(-2, 2)
         RangeInfo(u"x = %.1f ± %.1f cm", xrangeselection, lambda x, dx: (x, dx))
         disp = make.info_label('BL', comp, title="titre")
     """
@@ -912,52 +1013,76 @@ class RangeInfo(ObjectInfo):
     def __init__(
         self,
         label: str,
-        xrangeselection: XRangeSelection,
+        rangeselection: XRangeSelection | YRangeSelection,
         function: Callable | None = None,
     ) -> None:
         self.label = str(label)
-        self.range = xrangeselection
+        self.range = rangeselection
         if function is None:
 
-            def function(x, dx):
-                return x, dx
+            def function(v, dv):
+                return v, dv
 
         self.func = function
 
     def get_text(self) -> str:
         """Return the text to be displayed"""
-        x0, x1 = self.range.get_range()
-        x = 0.5 * (x0 + x1)
-        dx = 0.5 * (x1 - x0)
-        return self.label % self.func(x, dx)
+        v0, v1 = self.range.get_range()
+        v = 0.5 * (v0 + v1)
+        dv = 0.5 * (v1 - v0)
+
+        # Get result from function
+        result = self.func(v, dv)
+
+        # Check if we need to format as datetime
+        plot = self.range.plot()
+        if plot is not None:
+            # Determine which axis this range is on
+            if isinstance(self.range, XRangeSelection):
+                axis_id = self.range.xAxis()
+            else:
+                axis_id = self.range.yAxis()
+
+            # Value checker: returns True if value matches v or dv (likely datetime)
+            def is_range_value(val, _idx):
+                return abs(val - v) < 1e-10 or abs(abs(val) - abs(dv)) < 1e-10
+
+            label, result = self._format_values_for_datetime_axis(
+                plot, axis_id, self.label, result, is_range_value
+            )
+            return label % result
+
+        return self.label % result
 
 
-class RangeComputation(ObjectInfo):
-    """ObjectInfo showing curve computations relative to a XRangeSelection
+class XRangeComputation(ObjectInfo):
+    """ObjectInfo showing curve computations relative to a `XRangeSelection`
     shape
 
     Args:
         label: formatted string
         curve: CurveItem object
-        xrangeselection: XRangeSelection object
-        function: input arguments are x, y arrays (extraction of arrays
-         corresponding to the xrangeselection X-axis range)
+        rangeselection: `XRangeSelection` object
+        function: callback function to compute the text to be displayed depending on the
+         range and eventually the curve data. Input arguments are x, y arrays
+        (extraction of associated curve data corresponding to the `rangeselection`
+        X-axis range).
     """
 
     def __init__(
         self,
         label: str,
         curve: CurveItem,
-        xrangeselection: XRangeSelection,
+        rangeselection: XRangeSelection,
         function: Callable | None = None,
     ) -> None:
         self.label = str(label)
         self.curve = curve
-        self.range = xrangeselection
+        self.range = rangeselection
         if function is None:
 
-            def function(x, dx):
-                return x, dx
+            def function(v, dv):
+                return v, dv
 
         self.func = function
 
@@ -973,9 +1098,9 @@ class RangeComputation(ObjectInfo):
         """Return the text to be displayed"""
         x0, x1 = self.range.get_range()
         data = self.curve.get_data()
-        X = data[0]
-        i0 = X.searchsorted(x0)
-        i1 = X.searchsorted(x1)
+        xdata = data[0]
+        i0 = xdata.searchsorted(x0)
+        i1 = xdata.searchsorted(x1)
         if i0 > i1:
             i0, i1 = i1, i0
         vectors = []
@@ -986,7 +1111,73 @@ class RangeComputation(ObjectInfo):
                 vectors.append(np.array([np.nan]))
             else:
                 vectors.append(vector[i0:i1])
-        return self.label % self.func(*vectors)
+
+        # Get result from function
+        result = self.func(*vectors)
+
+        # Format values considering datetime axis
+        plot = self.curve.plot()
+        if plot is not None:
+            # Check if x-axis is datetime
+            x_axis = self.curve.xAxis()
+
+            # Compute x-statistics to identify x-coordinates in result
+            x_vector = vectors[0]
+            x_stats = set()
+            if x_vector is not None and len(x_vector) > 0:
+                x_stats = {x_vector.min(), x_vector.max(), x_vector.mean()}
+
+            # Value checker: returns True if value matches an x-statistic
+            def is_x_coordinate(val, _idx):
+                return any(
+                    abs(val - stat) < 1e-10 for stat in x_stats if not np.isnan(stat)
+                )
+
+            label, result = self._format_values_for_datetime_axis(
+                plot, x_axis, self.label, result, is_x_coordinate
+            )
+            return label % result
+
+        return self.label % result
+
+
+RangeComputation = XRangeComputation  # For backward compatibility
+
+
+class YRangeComputation(ObjectInfo):
+    """ObjectInfo showing computations relative to a `YRangeSelection` shape
+
+    Args:
+        label: formatted string
+        rangeselection: `YRangeSelection` object
+        function: callback function to compute the text to be displayed.
+
+    .. note::
+
+        Unlike the `XRangeSelection`, the `YRangeSelection` does not depend on any
+        curve data, the input arguments of the callback function are simply ymin, ymax
+        values (extraction of the `rangeselection` Y-axis range).
+    """
+
+    def __init__(
+        self,
+        label: str,
+        rangeselection: YRangeSelection,
+        function: Callable,
+    ) -> None:
+        self.label = str(label)
+        self.range = rangeselection
+        if function is None:
+
+            def function(v, dv):
+                return v, dv
+
+        self.func = function
+
+    def get_text(self) -> str:
+        """Return the text to be displayed"""
+        y0, y1 = self.range.get_range()
+        return self.label % self.func(y0, y1)
 
 
 class RangeComputation2d(ObjectInfo):
@@ -1021,22 +1212,22 @@ class DataInfoLabel(LabelItem):
 
     Args:
         labelparam: Label parameters
-        infos: List of objects implementing the ``get_text`` method
+        info: List of objects implementing the ``get_text`` method
     """
 
     __implements__ = (IBasePlotItem,)
 
     def __init__(
-        self, labelparam: LabelParam | None = None, infos: list[Any] | None = None
+        self, labelparam: LabelParam | None = None, info: list[Any] | None = None
     ) -> None:
         super().__init__(None, labelparam)
-        if isinstance(infos, ObjectInfo):
-            infos = [infos]
-        self.infos = infos
+        if isinstance(info, ObjectInfo):
+            info = [info]
+        self.info = info
 
     def __reduce__(self) -> tuple[type, tuple]:
         """Return a tuple containing the constructor and its arguments"""
-        return (self.__class__, (self.labelparam, self.infos))
+        return (self.__class__, (self.labelparam, self.info))
 
     def types(self) -> tuple[type[IItemType], ...]:
         """Returns a group or category for this item.
@@ -1054,6 +1245,6 @@ class DataInfoLabel(LabelItem):
             text = ["<b>%s</b>" % title]
         else:
             text = []
-        for info in self.infos:
+        for info in self.info:
             text.append(info.get_text())
         self.set_text("<br/>".join(text))
