@@ -533,7 +533,7 @@ def plotyy(x1, y1, x2, y2):
         import numpy as np
         x = np.linspace(-5, 5, 1000)
         plotyy(x, np.sin(x), x, np.cos(x))
-        ylabel("sinus", "cosinus")
+        ylabel("sine", "cosine")
         show()
     """
     axe = gca()
@@ -829,7 +829,7 @@ def savefig(fname, format=None):
         format = fname.rsplit(".", 1)[-1].lower()
         fmts = [fmt.data().decode() for fmt in QG.QImageWriter.supportedImageFormats()]
         assert format in fmts, _(
-            "Function 'savefig' currently supports the " "following formats:\n%s"
+            "Function 'savefig' currently supports the following formats:\n%s"
         ) % ", ".join(fmts)
     else:
         format = format.lower()
